@@ -102,6 +102,10 @@ def filter_kw(
     return kw
 
 
+def safe_execute(fn: Any, kw: Dict[str, Any], *, strict: bool = False) -> Any:
+    return fn(**filter_kw(fn, kw, strict=strict))
+
+
 def get_num_positional_args(fn: Callable) -> Union[int, float]:
     signature = inspect.signature(fn)
     counter = 0
@@ -460,8 +464,8 @@ class WithRegister(Generic[T]):
         name: str,
         *,
         allow_duplicate: bool = False,
-    ) -> Callable[[Type[T]], Type[T]]:
-        def before(cls_: Type[T]) -> None:
+    ) -> Callable:
+        def before(cls_: Type) -> None:
             cls_.__identifier__ = name
 
         return register_core(
@@ -472,7 +476,7 @@ class WithRegister(Generic[T]):
         )
 
     @classmethod
-    def remove(cls, name: str) -> Callable[[Type[T]], Type[T]]:
+    def remove(cls, name: str) -> Callable:
         return cls.d.pop(name)
 
     @classmethod
